You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@harmony.apache.org by mc...@apache.org on 2008/05/22 15:34:09 UTC

svn commit: r659108 [17/19] - in /harmony/enhanced/drlvm/trunk/vm: em/src/ gc_gen/src/common/ gc_gen/src/mark_compact/ gc_gen/src/mark_sweep/ gc_gen/src/semi_space/ gc_gen/src/trace_forward/ include/open/ interpreter/src/ jitrino/src/codegenerator/ jit...

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.cpp Thu May 22 06:33:38 2008
@@ -449,10 +449,10 @@
 }
 
 
-uint32
+U_32
 methodGetStacknGCInfoBlockSize(Method_Handle method, JIT_Handle jit)
 {
-    uint32  size = method_get_info_block_size_jit(method, jit);
+    U_32  size = method_get_info_block_size_jit(method, jit);
     return (size - sizeof(void *));     // skip the header
 }
 
@@ -463,12 +463,12 @@
 
 
 // TODO: free TLS key on JIT deinitilization
-uint32
+U_32
 VMInterface::flagTLSSuspendRequestOffset(){
-    return (uint32)vm_tls_get_request_offset();
+    return (U_32)vm_tls_get_request_offset();
 }
 
-uint32
+U_32
 VMInterface::flagTLSThreadStateOffset() {
     static UDATA key = 0;
     static size_t offset = 0;
@@ -477,12 +477,12 @@
         offset = vm_tls_get_offset(key);
     }
     assert(fit32(offset));
-    return (uint32)offset;
+    return (U_32)offset;
 }
 
-int32
+I_32
 VMInterface::getTLSBaseOffset() {
-    return (int32) vm_get_tls_offset_in_segment();
+    return (I_32) vm_get_tls_offset_in_segment();
 }
 
 bool
@@ -596,12 +596,12 @@
     return class_get_depth((Class_Handle) vmTypeHandle);
 }
 
-uint32
+U_32
 VMInterface::getArrayLengthOffset() {
     return vector_get_length_offset();
 }
 
-uint32
+U_32
 VMInterface::getArrayElemOffset(void* vmElemTypeHandle,bool isUnboxed) {
     //if (isUnboxed)
       //  return vector_first_element_offset_unboxed((Class_Handle) vmElemTypeHandle);
@@ -617,12 +617,12 @@
     return class_is_instanceof((Class_Handle) vmTypeHandle1,(Class_Handle) vmTypeHandle2)?true:false;
 }    
 
-uint32
+U_32
 VMInterface::getArrayElemSize(void * vmTypeHandle) {
     return class_get_array_element_size((Class_Handle) vmTypeHandle);
 }
 
-uint32
+U_32
 VMInterface::getObjectSize(void * vmTypeHandle) {
     return class_get_object_size((Class_Handle) vmTypeHandle);
 }
@@ -663,7 +663,7 @@
     return (void *) class_get_allocation_handle((Class_Handle) vmTypeHandle);
 }
 
-uint32      VMInterface::getVTableOffset()
+U_32      VMInterface::getVTableOffset()
 {
     return object_get_vtable_offset();
 }
@@ -684,7 +684,7 @@
 ///////////////////////// MethodDesc //////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
 
-MethodDesc::MethodDesc(Method_Handle m, JIT_Handle jit, CompilationInterface* ci, uint32 id)
+MethodDesc::MethodDesc(Method_Handle m, JIT_Handle jit, CompilationInterface* ci, U_32 id)
 : TypeMemberDesc(id, ci), drlMethod(m),
 methodSig(method_get_signature(m)),
 handleMap(NULL),
@@ -711,22 +711,22 @@
 //
 
 const U_8*   MethodDesc::getByteCodes() const   {return method_get_bytecode(drlMethod);}
-uint32       MethodDesc::getByteCodeSize() const {return (uint32) method_get_bytecode_length(drlMethod);}
+U_32       MethodDesc::getByteCodeSize() const {return (U_32) method_get_bytecode_length(drlMethod);}
 uint16       MethodDesc::getMaxStack() const    {return (uint16) method_get_max_stack(drlMethod);}
-uint32       MethodDesc::getNumHandlers() const {return method_get_exc_handler_number(drlMethod);}
-uint32       MethodDesc::getOffset() const      {return method_get_vtable_offset(drlMethod);}
+U_32       MethodDesc::getNumHandlers() const {return method_get_exc_handler_number(drlMethod);}
+U_32       MethodDesc::getOffset() const      {return method_get_vtable_offset(drlMethod);}
 void*        MethodDesc::getIndirectAddress() const {return method_get_indirect_address(drlMethod);}
 void*        MethodDesc::getNativeAddress() const {return method_get_native_func_addr(drlMethod);}
 
-uint32    MethodDesc::getNumVars() const        {return method_get_max_locals(drlMethod);}
+U_32    MethodDesc::getNumVars() const        {return method_get_max_locals(drlMethod);}
 
-uint32    
+U_32    
 MethodDesc::getNumParams() const {
     return method_args_get_number(methodSig);
 }
 
 Type*    
-MethodDesc::getParamType(uint32 paramIndex) const {
+MethodDesc::getParamType(U_32 paramIndex) const {
     Type_Info_Handle typeHandle = method_args_get_type_info(methodSig,paramIndex);
     return compilationInterface->getTypeFromDrlVMTypeHandle(typeHandle);
 }
@@ -755,15 +755,15 @@
     return methodGetStacknGCInfoBlock(drlMethod, getJitHandle());
 }
 
-uint32       MethodDesc::getInfoBlockSize() const {
+U_32       MethodDesc::getInfoBlockSize() const {
     return methodGetStacknGCInfoBlockSize(drlMethod, getJitHandle());
 }
 
-U_8* MethodDesc::getCodeBlockAddress(int32 id) const {
+U_8* MethodDesc::getCodeBlockAddress(I_32 id) const {
     return method_get_code_block_addr_jit_new(drlMethod,getJitHandle(), id);
 }
 
-uint32       MethodDesc::getCodeBlockSize(int32 id) const {
+U_32       MethodDesc::getCodeBlockSize(I_32 id) const {
     return method_get_code_block_size_jit_new(drlMethod,getJitHandle(), id);
 }
 
@@ -779,7 +779,7 @@
 }
 
 const char*
-CompilationInterface::getSignatureString(MethodDesc* enclosingMethodDesc, uint32 methodToken) {
+CompilationInterface::getSignatureString(MethodDesc* enclosingMethodDesc, U_32 methodToken) {
     Class_Handle enclosingDrlVMClass = enclosingMethodDesc->getParentHandle();
     return class_cp_get_entry_descriptor(enclosingDrlVMClass, (unsigned short)methodToken);
 }
@@ -795,12 +795,12 @@
 }
 
 void        
-MethodDesc::setNumExceptionHandler(uint32 numHandlers) {
+MethodDesc::setNumExceptionHandler(U_32 numHandlers) {
     method_set_num_target_handlers(drlMethod,getJitHandle(),numHandlers);
 }
 
 void
-MethodDesc::setExceptionHandlerInfo(uint32 exceptionHandlerNumber,
+MethodDesc::setExceptionHandlerInfo(U_32 exceptionHandlerNumber,
                                     U_8*   startAddr,
                                     U_8*   endAddr,
                                     U_8*   handlerAddr,
@@ -866,7 +866,7 @@
     return compilationInterface->getTypeFromDrlVMTypeHandle(typeHandle);
 }
 
-uint32
+U_32
 FieldDesc::getOffset() const {
     return field_get_offset(drlField);
 }
@@ -908,7 +908,7 @@
         bool lazy = typeManager.isLazyResolutionMode();
         if (lazy && !type_info_is_resolved(typeHandle)) {
             Type* elemType = typeManager.getUnresolvedObjectType();
-            uint32 dims =  type_info_get_num_array_dimensions(typeHandle);
+            U_32 dims =  type_info_get_num_array_dimensions(typeHandle);
             Type* arrayType = NULL;
             while (dims!=0) {
                 arrayType = typeManager.getArrayType(arrayType==NULL ? elemType : arrayType);
@@ -991,14 +991,14 @@
 
 const void* 
 CompilationInterface::getStringInternAddr(MethodDesc* enclosingMethodDesc,
-                                                uint32 stringToken) {
+                                                U_32 stringToken) {
     Class_Handle enclosingDrlVMClass = enclosingMethodDesc->getParentHandle();
     return class_get_const_string_intern_addr(enclosingDrlVMClass,stringToken);
 }
 
 Type*
 CompilationInterface::getConstantType(MethodDesc* enclosingMethodDesc,
-                                         uint32 constantToken) {
+                                         U_32 constantToken) {
     Class_Handle enclosingDrlVMClass = enclosingMethodDesc->getParentHandle();
     VM_Data_Type drlType = class_cp_get_const_type(enclosingDrlVMClass,constantToken);
     switch (drlType) {
@@ -1016,7 +1016,7 @@
 
 const void*
 CompilationInterface::getConstantValue(MethodDesc* enclosingMethodDesc,
-                                          uint32 constantToken) {
+                                          U_32 constantToken) {
     Class_Handle enclosingDrlVMClass = enclosingMethodDesc->getParentHandle();
     return class_cp_get_const_addr(enclosingDrlVMClass,constantToken);
 }
@@ -1040,7 +1040,7 @@
 }
 
 void CompilationInterface::sendCompiledMethodLoadEvent(MethodDesc* methodDesc, MethodDesc* outerDesc,
-        uint32 codeSize, void* codeAddr, uint32 mapLength, 
+        U_32 codeSize, void* codeAddr, U_32 mapLength, 
         AddrLocation* addrLocationMap, void* compileInfo) {
 
     Method_Handle method = methodDesc->getMethodHandle();
@@ -1142,7 +1142,7 @@
     method_unlock(mh);
 }
 
-U_8* CompilationInterface::allocateCodeBlock(size_t size, size_t alignment, CodeBlockHeat heat, int32 id, 
+U_8* CompilationInterface::allocateCodeBlock(size_t size, size_t alignment, CodeBlockHeat heat, I_32 id, 
 bool simulate) {
     return method_allocate_code_block(methodToCompile->getMethodHandle(), getJitHandle(), 
         size, alignment, heat, id, simulate ? CAA_Simulate : CAA_Allocate);
@@ -1166,12 +1166,12 @@
     return getMethodDesc(method, getJitHandle());
 }
 
-static uint32 getArrayDims(Class_Handle cl, uint32 cpIndex) {
+static U_32 getArrayDims(Class_Handle cl, U_32 cpIndex) {
     return class_cp_get_num_array_dimensions(cl, (unsigned short)cpIndex);
 }
 
-static NamedType* getUnresolvedType(TypeManager& typeManager, Class_Handle enclClass, uint32 cpIndex) {
-    uint32 arrayDims = getArrayDims(enclClass, cpIndex);
+static NamedType* getUnresolvedType(TypeManager& typeManager, Class_Handle enclClass, U_32 cpIndex) {
+    U_32 arrayDims = getArrayDims(enclClass, cpIndex);
     NamedType * res = typeManager.getUnresolvedObjectType();
     while (arrayDims > 0) {
         res = typeManager.getArrayType(res);
@@ -1180,7 +1180,7 @@
     return res;
 }
 
-NamedType* CompilationInterface::resolveNamedType(Class_Handle enclClass, uint32 cpIndex) {
+NamedType* CompilationInterface::resolveNamedType(Class_Handle enclClass, U_32 cpIndex) {
     //this method is allowed to use only for unresolved exception types
     Class_Handle ch = resolve_class(compileHandle,enclClass,cpIndex);
     if (ch == NULL) {
@@ -1192,7 +1192,7 @@
     return res;
 }
 
-NamedType* CompilationInterface::getNamedType(Class_Handle enclClass, uint32 cpIndex, ResolveNewCheck checkNew) {
+NamedType* CompilationInterface::getNamedType(Class_Handle enclClass, U_32 cpIndex, ResolveNewCheck checkNew) {
     Class_Handle ch = NULL;
     if (typeManager.isLazyResolutionMode() && !class_cp_is_entry_resolved(enclClass, cpIndex)) {
         const char* className = class_cp_get_class_name(enclClass, cpIndex);
@@ -1222,7 +1222,7 @@
 }
 
 MethodDesc* 
-CompilationInterface::getSpecialMethod(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getSpecialMethod(Class_Handle enclClass, U_32 cpIndex) {
     Method_Handle res = NULL;
     bool lazy = typeManager.isLazyResolutionMode();
     if (!lazy || class_cp_is_entry_resolved(enclClass, cpIndex)) {
@@ -1233,7 +1233,7 @@
 }    
 
 MethodDesc* 
-CompilationInterface::getInterfaceMethod(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getInterfaceMethod(Class_Handle enclClass, U_32 cpIndex) {
     Method_Handle res = NULL;
     bool lazy = typeManager.isLazyResolutionMode();
     if (!lazy || class_cp_is_entry_resolved(enclClass, cpIndex)) {
@@ -1244,7 +1244,7 @@
 }    
 
 MethodDesc* 
-CompilationInterface::getStaticMethod(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getStaticMethod(Class_Handle enclClass, U_32 cpIndex) {
     Method_Handle res = NULL;
     bool lazy = typeManager.isLazyResolutionMode();
     if (!lazy || class_cp_is_entry_resolved(enclClass, cpIndex)) {
@@ -1255,7 +1255,7 @@
 }    
 
 MethodDesc* 
-CompilationInterface::getVirtualMethod(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getVirtualMethod(Class_Handle enclClass, U_32 cpIndex) {
     Method_Handle res = NULL;
     bool lazy = typeManager.isLazyResolutionMode();
     if (!lazy || class_cp_is_entry_resolved(enclClass, cpIndex)) {
@@ -1267,7 +1267,7 @@
 
 
 FieldDesc*  
-CompilationInterface::getNonStaticField(Class_Handle enclClass, uint32 cpIndex, bool putfield) {
+CompilationInterface::getNonStaticField(Class_Handle enclClass, U_32 cpIndex, bool putfield) {
     Field_Handle res = NULL;
     bool lazy = typeManager.isLazyResolutionMode();
     if (!lazy || class_cp_is_entry_resolved(enclClass, cpIndex)) {
@@ -1281,7 +1281,7 @@
 
 
 FieldDesc*  
-CompilationInterface::getStaticField(Class_Handle enclClass, uint32 cpIndex, bool putfield) {
+CompilationInterface::getStaticField(Class_Handle enclClass, U_32 cpIndex, bool putfield) {
     Field_Handle res = NULL;
     bool lazy = typeManager.isLazyResolutionMode();
     if (!lazy || class_cp_is_entry_resolved(enclClass, cpIndex)) {
@@ -1307,7 +1307,7 @@
 }
 
 Type*
-CompilationInterface::getFieldType(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getFieldType(Class_Handle enclClass, U_32 cpIndex) {
     VM_Data_Type drlType = class_cp_get_field_type(enclClass, (unsigned short)cpIndex);
     bool lazy = typeManager.isLazyResolutionMode();
     switch (drlType) {
@@ -1338,17 +1338,17 @@
 }
 
 const char* 
-CompilationInterface::getMethodName(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getMethodName(Class_Handle enclClass, U_32 cpIndex) {
     return class_cp_get_entry_name(enclClass, cpIndex);
 }
 
 const char* 
-CompilationInterface::getMethodClassName(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getMethodClassName(Class_Handle enclClass, U_32 cpIndex) {
     return class_cp_get_entry_class_name(enclClass, cpIndex);
 }
 
 const char* 
-CompilationInterface::getFieldSignature(Class_Handle enclClass, uint32 cpIndex) {
+CompilationInterface::getFieldSignature(Class_Handle enclClass, U_32 cpIndex) {
     return class_cp_get_entry_descriptor(enclClass, cpIndex);
 }
 
@@ -1384,7 +1384,7 @@
     vm_enumerate_root_reference(reference, FALSE);
 }
 
-void GCInterface::enumerateCompressedRootReference(uint32* reference) {
+void GCInterface::enumerateCompressedRootReference(U_32* reference) {
     vm_enumerate_compressed_root_reference(reference, FALSE);
 }
 
@@ -1396,7 +1396,7 @@
     //vm_check_if_monitor(reference, 0, 0, 0, FALSE, 1);
 }
 
-void ThreadDumpEnumerator::enumerateCompressedRootReference(uint32* reference) {
+void ThreadDumpEnumerator::enumerateCompressedRootReference(U_32* reference) {
     //vm_check_if_monitor(0, 0, reference, 0, FALSE, 2);
 }
 

Modified: harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/jitrino/src/vm/VMInterface.h Thu May 22 06:33:38 2008
@@ -76,17 +76,17 @@
     static void*       getRuntimeClassHandle(void* vmTypeHandle);
     static void*       getAllocationHandle(void* vmTypeHandle);
     static bool        isSubClassOf(void* vmTypeHandle1,void* vmTypeHandle2);
-    static uint32      getArrayElemOffset(void* vmElemTypeHandle,bool isUnboxed);
-    static uint32      getArrayElemSize(void * vmTypeHandle);
-    static uint32      getObjectSize(void * vmTypeHandle);
-    static uint32      getArrayLengthOffset();
+    static U_32      getArrayElemOffset(void* vmElemTypeHandle,bool isUnboxed);
+    static U_32      getArrayElemSize(void * vmTypeHandle);
+    static U_32      getObjectSize(void * vmTypeHandle);
+    static U_32      getArrayLengthOffset();
 
     static void*       getTypeHandleFromAllocationHandle(void* vmAllocationHandle);
     static void*       getTypeHandleFromVTable(void* vtHandle);
 
-    static uint32      flagTLSSuspendRequestOffset();
-    static uint32      flagTLSThreadStateOffset();
-    static int32       getTLSBaseOffset();
+    static U_32      flagTLSSuspendRequestOffset();
+    static U_32      flagTLSThreadStateOffset();
+    static I_32       getTLSBaseOffset();
     static bool        useFastTLSAccess();
 
 
@@ -94,7 +94,7 @@
     static bool          isVTableCompressed();
 
     // returns the offset of an object's virtual table
-    static uint32      getVTableOffset();
+    static U_32      getVTableOffset();
     // returns the base for all vtables (addend to compressed vtable pointer)
     static void*      getVTableBase();
 
@@ -126,11 +126,11 @@
 
 class TypeMemberDesc {
 public:
-    TypeMemberDesc(uint32 id, CompilationInterface* ci)
+    TypeMemberDesc(U_32 id, CompilationInterface* ci)
         : id(id), compilationInterface(ci) {}
     virtual ~TypeMemberDesc() {}
 
-    uint32      getId() const { return id; }
+    U_32      getId() const { return id; }
     NamedType*  getParentType();
     bool        isParentClassIsLikelyExceptionType() const;
 
@@ -144,7 +144,7 @@
     virtual bool        isStatic() const          = 0;
 
 protected:
-    uint32 id;
+    U_32 id;
     CompilationInterface* compilationInterface;
 
 };
@@ -152,7 +152,7 @@
 ///Field representation for resolved fields
 class FieldDesc : public TypeMemberDesc {
 public:
-    FieldDesc(Field_Handle field, CompilationInterface* ci, uint32 id) 
+    FieldDesc(Field_Handle field, CompilationInterface* ci, U_32 id) 
         : TypeMemberDesc(id, ci), drlField(field) {} 
 
         const char*   getName() const;
@@ -171,7 +171,7 @@
         bool          isVolatile() const;
         bool          isMagic() const;
         Type*         getFieldType();
-        uint32        getOffset() const; // for non-static fields
+        U_32        getOffset() const; // for non-static fields
         void*         getAddress() const; // for static fields
         Field_Handle  getFieldHandle() const  {return drlField; }
 
@@ -182,7 +182,7 @@
 ///Method representation for resolved methods
 class MethodDesc : public TypeMemberDesc {
 public:
-    MethodDesc(Method_Handle m, JIT_Handle jit, CompilationInterface* ci = NULL, uint32 id = 0);
+    MethodDesc(Method_Handle m, JIT_Handle jit, CompilationInterface* ci = NULL, U_32 id = 0);
 
         const char*  getName() const;
         const char*  getSignatureString() const;
@@ -208,9 +208,9 @@
         //
 
         const U_8*  getByteCodes() const;
-        uint32       getByteCodeSize() const;
+        U_32       getByteCodeSize() const;
         uint16       getMaxStack() const;
-        uint32       getNumHandlers() const;
+        U_32       getNumHandlers() const;
         void getHandlerInfo(unsigned short index, unsigned short* beginOffset, 
             unsigned short* endOffset, unsigned short* handlerOffset,
             unsigned short* handlerClassIndex) const;
@@ -220,9 +220,9 @@
         // accessors for method info, code and data
         //
         U_8*     getInfoBlock() const;
-        uint32   getInfoBlockSize() const;
-        U_8*     getCodeBlockAddress(int32 id) const;
-        uint32   getCodeBlockSize(int32 id) const;
+        U_32   getInfoBlockSize() const;
+        U_8*     getCodeBlockAddress(I_32 id) const;
+        U_32   getCodeBlockSize(I_32 id) const;
 
         // sets and gets MethodSideEffect property for the compiled method
         Method_Side_Effects getSideEffect() const;
@@ -231,8 +231,8 @@
         //
         //    Exception registration API. 
         //
-        void        setNumExceptionHandler(uint32 numHandlers);
-        void        setExceptionHandlerInfo(uint32 exceptionHandlerNumber,
+        void        setNumExceptionHandler(U_32 numHandlers);
+        void        setExceptionHandlerInfo(U_32 exceptionHandlerNumber,
             U_8* startAddr,
             U_8* endAddr,
             U_8* handlerAddr,
@@ -243,11 +243,11 @@
         //
         // DRL kernel
         //
-        uint32       getOffset() const;
+        U_32       getOffset() const;
         void*        getIndirectAddress() const;
         void*        getNativeAddress() const;
 
-        uint32    getNumVars() const;
+        U_32    getNumVars() const;
 
         Method_Handle    getMethodHandle() const   {return drlMethod;}
 
@@ -256,8 +256,8 @@
         void* getHandleMap() const {return handleMap;}
         void setHandleMap(void* hndMap) {handleMap = hndMap;}
 
-        uint32    getNumParams() const;
-        Type*     getParamType(uint32 paramIndex) const;
+        U_32    getNumParams() const;
+        Type*     getParamType(U_32 paramIndex) const;
         Type*     getReturnType() const;
 
 private:
@@ -305,26 +305,26 @@
     void*       getRuntimeHelperAddressForType(VM_RT_SUPPORT, Type*);
     MethodDesc* getMagicHelper(VM_RT_SUPPORT);
 
-    Type*      getFieldType(Class_Handle enclClass, uint32 cpIndex);
+    Type*      getFieldType(Class_Handle enclClass, U_32 cpIndex);
 
-    NamedType* getNamedType(Class_Handle enclClass, uint32 cpIndex, ResolveNewCheck check = ResolveNewCheck_NoCheck);
+    NamedType* getNamedType(Class_Handle enclClass, U_32 cpIndex, ResolveNewCheck check = ResolveNewCheck_NoCheck);
     Type*      getTypeFromDescriptor(Class_Handle enclClass, const char* descriptor);
 
     //this method is obsolete and will be removed. Use getNamedType if unsure.
-    NamedType* resolveNamedType(Class_Handle enclClass, uint32 cpIndex);
+    NamedType* resolveNamedType(Class_Handle enclClass, U_32 cpIndex);
 
 
-    static const char* getMethodName(Class_Handle enclClass, uint32 cpIndex);
-    static const char* getMethodClassName(Class_Handle enclClass, uint32 cpIndex);
-    static const char* getFieldSignature(Class_Handle enclClass, uint32 cpIndex);
+    static const char* getMethodName(Class_Handle enclClass, U_32 cpIndex);
+    static const char* getMethodClassName(Class_Handle enclClass, U_32 cpIndex);
+    static const char* getFieldSignature(Class_Handle enclClass, U_32 cpIndex);
 
-    MethodDesc* getStaticMethod(Class_Handle enclClass, uint32 cpIndex);
-    MethodDesc* getVirtualMethod(Class_Handle enclClass, uint32 cpIndex);
-    MethodDesc* getSpecialMethod(Class_Handle enclClass, uint32 cpIndex);
-    MethodDesc* getInterfaceMethod(Class_Handle enclClass, uint32 cpIndex);
+    MethodDesc* getStaticMethod(Class_Handle enclClass, U_32 cpIndex);
+    MethodDesc* getVirtualMethod(Class_Handle enclClass, U_32 cpIndex);
+    MethodDesc* getSpecialMethod(Class_Handle enclClass, U_32 cpIndex);
+    MethodDesc* getInterfaceMethod(Class_Handle enclClass, U_32 cpIndex);
 
-    FieldDesc*  getNonStaticField(Class_Handle enclClass, uint32 cpIndex, bool putfield);
-    FieldDesc*  getStaticField(Class_Handle enclClass, uint32 cpIndex, bool putfield);
+    FieldDesc*  getNonStaticField(Class_Handle enclClass, U_32 cpIndex, bool putfield);
+    FieldDesc*  getStaticField(Class_Handle enclClass, U_32 cpIndex, bool putfield);
 
     FieldDesc*  getFieldByName(Class_Handle enclClass, const char* name);
     MethodDesc* getMethodByName(Class_Handle enclClass, const char* name);
@@ -349,15 +349,15 @@
     MethodDesc* getOverridingMethod(NamedType *type, MethodDesc * methodDesc);
 
 
-    const void*  getStringInternAddr(MethodDesc* enclosingMethodDesc, uint32 stringToken);
-    Type*        getConstantType(MethodDesc* enclosingMethodDesc, uint32 constantToken);
-    const void*  getConstantValue(MethodDesc* enclosingMethodDesc, uint32 constantToken);
-    const char*  getSignatureString(MethodDesc* enclosingMethodDesc, uint32 methodToken);
+    const void*  getStringInternAddr(MethodDesc* enclosingMethodDesc, U_32 stringToken);
+    Type*        getConstantType(MethodDesc* enclosingMethodDesc, U_32 constantToken);
+    const void*  getConstantValue(MethodDesc* enclosingMethodDesc, U_32 constantToken);
+    const char*  getSignatureString(MethodDesc* enclosingMethodDesc, U_32 methodToken);
 
     // Memory allocation API
     // all of these are for the method being compiled
     U_8*   allocateCodeBlock(size_t size, size_t alignment, CodeBlockHeat heat, 
-        int32 id, bool simulate);
+        I_32 id, bool simulate);
 
     U_8*   allocateDataBlock(size_t size, size_t alignment);
 
@@ -411,7 +411,7 @@
     }
 
     void    sendCompiledMethodLoadEvent(MethodDesc* methodDesc, MethodDesc* outerDesc,
-        uint32 codeSize, void* codeAddr, uint32 mapLength, 
+        U_32 codeSize, void* codeAddr, U_32 mapLength, 
         AddrLocation* addrLocationMap, void* compileInfo);
 
     OpenMethodExecutionParams& getCompilationParams() const { 
@@ -458,7 +458,7 @@
     MethodDesc*                 methodToCompile;
     Compile_Handle              compileHandle;
     bool                        flushToZeroAllowed;
-    uint32                      nextMemberId;
+    U_32                      nextMemberId;
     OpenMethodExecutionParams&  compilation_params;
 };
 
@@ -469,7 +469,7 @@
 
     virtual void enumerateRootReference(void** reference);
 
-    virtual void enumerateCompressedRootReference(uint32* reference);
+    virtual void enumerateCompressedRootReference(U_32* reference);
 
     virtual void enumerateRootManagedReference(void** slotReference, size_t slotOffset);
 
@@ -484,7 +484,7 @@
 
     virtual void enumerateRootReference(void** reference);
 
-    virtual void enumerateCompressedRootReference(uint32* reference);
+    virtual void enumerateCompressedRootReference(U_32* reference);
 
     virtual void enumerateRootManagedReference(void** slotReference, size_t slotOffset);
 };
@@ -496,23 +496,23 @@
 class PersistentInstructionId {
 public:
     PersistentInstructionId() 
-        : methodDesc(NULL), localInstructionId((uint32)-1) {}
+        : methodDesc(NULL), localInstructionId((U_32)-1) {}
 
-        PersistentInstructionId(MethodDesc* methodDesc, uint32 localInstructionId) 
+        PersistentInstructionId(MethodDesc* methodDesc, U_32 localInstructionId) 
             : methodDesc(methodDesc), localInstructionId(localInstructionId) {}
 
             bool isValid() const { return (methodDesc != NULL); }
 
             MethodDesc& getMethodDesc() const { return *methodDesc; }
-            uint32 getLocalInstructionId() const { return localInstructionId; }
+            U_32 getLocalInstructionId() const { return localInstructionId; }
 
             // For IPF codegen to store block ids into pid
-            bool hasValidLocalInstructionId() const { return localInstructionId != (uint32)-1; }
+            bool hasValidLocalInstructionId() const { return localInstructionId != (U_32)-1; }
 
             bool operator==(const PersistentInstructionId& pid) { return methodDesc == pid.methodDesc && localInstructionId == pid.localInstructionId; }
 private:
     MethodDesc* methodDesc;     // The source method at point the id was generated
-    uint32 localInstructionId;  // The persistent local instruction id
+    U_32 localInstructionId;  // The persistent local instruction id
 };
 
 inline ::std::ostream& operator<<(::std::ostream& os, const PersistentInstructionId& pid) { 

Modified: harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/include/port_atomic.h Thu May 22 06:33:38 2008
@@ -236,8 +236,8 @@
 
 PORT_INLINE void * port_atomic_casptr(volatile void ** data, void * value, const void * comp) {
 #if defined(_IA32_)
-    uint32 Exchange = (uint32)value;
-    uint32 Comperand = (uint32)comp;
+    U_32 Exchange = (U_32)value;
+    U_32 Comperand = (U_32)comp;
     __asm__ __volatile__(
         "lock cmpxchgl %1, (%2)"
         :"=a"(Comperand)

Modified: harmony/enhanced/drlvm/trunk/vm/port/include/port_dso.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/include/port_dso.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/include/port_dso.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/include/port_dso.h Thu May 22 06:33:38 2008
@@ -89,7 +89,7 @@
 */
 APR_DECLARE(apr_status_t) port_dso_load_ex(apr_dso_handle_t** handle,
                                       const char* path,
-                                      uint32 mode,
+                                      U_32 mode,
                                       apr_pool_t* pool);
 
 

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/atomic/linux_ipf/port_atomic_asm.asm Thu May 22 06:33:38 2008
@@ -72,7 +72,7 @@
 	.global port_atomic_cas32#
 	.align 32
 port_atomic_cas32:
-	// r32 -- Destination (uint32 *)
+	// r32 -- Destination (U_32 *)
 	// r33 -- Exchange
 	// r34 -- Comperand
 	// r35 -- for save ar.pfs

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/crash_handler/ia32/native_unwind_arch.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/crash_handler/ia32/native_unwind_arch.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/crash_handler/ia32/native_unwind_arch.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/crash_handler/ia32/native_unwind_arch.cpp Thu May 22 06:33:38 2008
@@ -31,7 +31,7 @@
     if (!native_is_in_code(context, addr))
         return 0;
 
-    uint32 len = DecoderBase::decode(addr, &inst);
+    U_32 len = DecoderBase::decode(addr, &inst);
 
     if (len == 0 ||
         inst.mn != Mnemonic_CALL ||
@@ -39,7 +39,7 @@
         return 0;
 
     if (target && inst.operands[0].is_imm())
-        *target = (void*)((uint32)addr + len + inst.operands[0].imm());
+        *target = (void*)((U_32)addr + len + inst.operands[0].imm());
 
     return len;
 }
@@ -97,9 +97,9 @@
     if (native_is_in_stack(context, esp) &&
         (native_is_in_code(context, eip)))
     {
-        regs->ebp = (uint32)ebp;
-        regs->esp = (uint32)esp;
-        regs->eip = (uint32)eip;
+        regs->ebp = (U_32)ebp;
+        regs->esp = (U_32)esp;
+        regs->eip = (U_32)eip;
         return true;
     }
 
@@ -108,9 +108,9 @@
 
 static bool fill_regs_from_sp(UnwindContext* context, Registers* regs, void** sp)
 {
-    regs->esp = (uint32)(sp + 1);
-    regs->eip = (uint32)*sp;
-    regs->ebp = native_is_in_stack(context, sp[-1]) ? (uint32)sp[-1] : regs->esp;
+    regs->esp = (U_32)(sp + 1);
+    regs->eip = (U_32)*sp;
+    regs->ebp = native_is_in_stack(context, sp[-1]) ? (U_32)sp[-1] : regs->esp;
     return true;
 }
 

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_defs.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_defs.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_defs.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_defs.h Thu May 22 06:33:38 2008
@@ -443,21 +443,21 @@
 //
 // double -> float
 Mnemonic_CVTSD2SS,                      // Convert Scalar Double-Precision Floating-Point Value to Scalar Single-Precision Floating-Point Value
-// double -> int32
+// double -> I_32
 Mnemonic_CVTSD2SI,                      // Convert Scalar Double-Precision Floating-Point Value to Doubleword Integer
-// double [truncated] -> int32
+// double [truncated] -> I_32
 Mnemonic_CVTTSD2SI,                     // Convert with Truncation Scalar Double-Precision Floating-Point Value to Signed Doubleword Integer
 //
 // float -> double
 Mnemonic_CVTSS2SD,                      // Convert Scalar Single-Precision Floating-Point Value to Scalar Double-Precision Floating-Point Value
-// float -> int32
+// float -> I_32
 Mnemonic_CVTSS2SI,                      // Convert Scalar Single-Precision Floating-Point Value to Doubleword Integer
-// float [truncated] -> int32
+// float [truncated] -> I_32
 Mnemonic_CVTTSS2SI,                     // Convert with Truncation Scalar Single-Precision Floating-Point Value to Doubleword Integer
 //
-// int32 -> double
+// I_32 -> double
 Mnemonic_CVTSI2SD,                      // Convert Doubleword Integer to Scalar Double-Precision Floating-Point Value
-// int32 -> float
+// I_32 -> float
 Mnemonic_CVTSI2SS,                      // Convert Doubleword Integer to Scalar Single-Precision Floating-Point Value
 
 Mnemonic_COMISD,                        // Compare Scalar Ordered Double-Precision Floating-Point Values and Set EFLAGS

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_tabl.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_tabl.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_tabl.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/enc_tabl.cpp Thu May 22 06:33:38 2008
@@ -528,7 +528,7 @@
 END_OPCODES()
 END_MNEMONIC()
 
-// double -> int32
+// double -> I_32
 BEGIN_MNEMONIC(CVTSD2SI, MF_NONE, D_U )
 BEGIN_OPCODES()
     {OpcodeInfo::all,     {0xF2, 0x0F, 0x2D, _r},      {r32, xmm_m64}, D_U },
@@ -536,7 +536,7 @@
 END_OPCODES()
 END_MNEMONIC()
 
-// double [truncated] -> int32
+// double [truncated] -> I_32
 BEGIN_MNEMONIC(CVTTSD2SI, MF_NONE, D_U )
 BEGIN_OPCODES()
     {OpcodeInfo::all,     {0xF2, 0x0F, 0x2C, _r},      {r32, xmm_m64}, D_U },
@@ -551,7 +551,7 @@
 END_OPCODES()
 END_MNEMONIC()
 
-// float -> int32
+// float -> I_32
 BEGIN_MNEMONIC(CVTSS2SI, MF_NONE, D_U )
 BEGIN_OPCODES()
     {OpcodeInfo::all,     {0xF3, 0x0F, 0x2D, _r},         {r32, xmm_m32}, D_U},
@@ -559,7 +559,7 @@
 END_OPCODES()
 END_MNEMONIC()
 
-// float [truncated] -> int32
+// float [truncated] -> I_32
 BEGIN_MNEMONIC(CVTTSS2SI, MF_NONE, D_U )
 BEGIN_OPCODES()
     {OpcodeInfo::all,     {0xF3, 0x0F, 0x2C, _r},         {r32, xmm_m32}, D_U},
@@ -567,7 +567,7 @@
 END_OPCODES()
 END_MNEMONIC()
 
-// int32 -> double
+// I_32 -> double
 BEGIN_MNEMONIC(CVTSI2SD, MF_NONE, D_U )
 BEGIN_OPCODES()
     {OpcodeInfo::all,     {0xF2, 0x0F, 0x2A, _r},         {xmm64, r_m32}, D_U},
@@ -575,7 +575,7 @@
 END_OPCODES()
 END_MNEMONIC()
 
-// int32 -> float
+// I_32 -> float
 BEGIN_MNEMONIC(CVTSI2SS, MF_NONE, D_U )
 BEGIN_OPCODES()
     {OpcodeInfo::all,     {0xF3, 0x0F, 0x2A, _r},         {xmm32, r_m32}, D_U},

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.h Thu May 22 06:33:38 2008
@@ -222,14 +222,14 @@
         int64           value;
         unsigned char   bytes[8];
 #else
-        int32           value;
+        I_32           value;
         unsigned char   bytes[4];
 #endif
     };
     Opnd_Size           size;
 
 public:
-    Imm_Opnd(int32 val): Opnd(Imm), value(val), size(size_32) {
+    Imm_Opnd(I_32 val): Opnd(Imm), value(val), size(size_32) {
         if (CHAR_MIN <= val && val <= CHAR_MAX) {
             size = size_8;
         }
@@ -250,7 +250,7 @@
             assert(val == (int64)(int16)val);
             break;
         case size_32:
-            assert(val == (int64)(int32)val);
+            assert(val == (int64)(I_32)val);
             break;
         case size_64:
             break;
@@ -265,14 +265,14 @@
 
 #else
 
-    Imm_Opnd(Opnd_Size sz, int32 val): Opnd(Imm), value(val), size(sz) {
+    Imm_Opnd(Opnd_Size sz, I_32 val): Opnd(Imm), value(val), size(sz) {
 #ifndef NDEBUG
         switch (size) {
         case size_8:
-            assert((int32)val == (int32)(int8)val);
+            assert((I_32)val == (I_32)(int8)val);
             break;
         case size_16:
-            assert((int32)val == (int32)(int16)val);
+            assert((I_32)val == (I_32)(int16)val);
             break;
         case size_32:
             break;
@@ -284,7 +284,7 @@
 #endif // NDEBUG
     }
     
-    int32 get_value() const { return value; }
+    I_32 get_value() const { return value; }
 
 #endif
     Opnd_Size get_size(void) const { return size; }
@@ -331,11 +331,11 @@
 
 public:
     //M_Opnd(Opnd_Size sz): RM_Opnd(Mem, K_M, sz), m_disp(0), m_scale(0), m_index(n_reg), m_base(n_reg) {}
-    M_Opnd(int32 disp):
+    M_Opnd(I_32 disp):
         RM_Opnd(Mem), m_disp(disp), m_scale(0), m_index(n_reg), m_base(n_reg) {}
-    M_Opnd(Reg_No rbase, int32 rdisp): 
+    M_Opnd(Reg_No rbase, I_32 rdisp): 
         RM_Opnd(Mem), m_disp(rdisp), m_scale(0), m_index(n_reg), m_base(rbase) {}
-    M_Opnd(int32 disp, Reg_No rbase, Reg_No rindex, unsigned scale):
+    M_Opnd(I_32 disp, Reg_No rbase, Reg_No rindex, unsigned scale):
         RM_Opnd(Mem), m_disp(disp), m_scale(scale), m_index(rindex), m_base(rbase) {}
     M_Opnd(const M_Opnd & that) : RM_Opnd(Mem), 
         m_disp((int)that.m_disp.get_value()), m_scale((int)that.m_scale.get_value()),
@@ -354,7 +354,7 @@
 class M_Base_Opnd: public M_Opnd {
 
 public:
-    M_Base_Opnd(Reg_No base, int32 disp) : M_Opnd(disp, base, n_reg, 0) {}
+    M_Base_Opnd(Reg_No base, I_32 disp) : M_Opnd(disp, base, n_reg, 0) {}
 
 private:
     // disallow copying - but it leads to ICC errors #734 in encoder.inl
@@ -368,7 +368,7 @@
 class M_Index_Opnd : public M_Opnd {
 
 public:
-    M_Index_Opnd(Reg_No base, Reg_No index, int32 disp, unsigned scale):
+    M_Index_Opnd(Reg_No base, Reg_No index, I_32 disp, unsigned scale):
         M_Opnd(disp, base, index, scale) {}
 
 private:
@@ -567,7 +567,7 @@
 ENCODER_DECLARE_EXPORT char *jump(char * stream, char *target);
 
 // jump with displacement
-//char * jump(char * stream, int32 disp);
+//char * jump(char * stream, I_32 disp);
 
 // conditional branch with 8-bit branch offset
 ENCODER_DECLARE_EXPORT char * branch8(char * stream, ConditionCode cc, const Imm_Opnd & imm, InstrPrefix prefix = no_prefix);
@@ -579,7 +579,7 @@
 //char * branch(char * stream, ConditionCode cc, const char * target, InstrPrefix prefix = no_prefix);
 
 // conditional branch with displacement immediate
-ENCODER_DECLARE_EXPORT char * branch(char * stream, ConditionCode cc, int32 disp, InstrPrefix prefix = no_prefix);
+ENCODER_DECLARE_EXPORT char * branch(char * stream, ConditionCode cc, I_32 disp, InstrPrefix prefix = no_prefix);
 
 // call with displacement
 ENCODER_DECLARE_EXPORT char * call(char * stream, const Imm_Opnd & imm);

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.inl
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.inl?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.inl (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/encoder/ia32_em64t/encoder.inl Thu May 22 06:33:38 2008
@@ -620,7 +620,7 @@
     stream = mov(stream, rax_opnd, Imm_Opnd(size_64, (int64)target), size_64);    
     return jump(stream, rax_opnd, size_64);
 #else
-    int32 offset = target - stream;
+    I_32 offset = target - stream;
     // sub 2 bytes for the short version
     offset -= 2;
     if (fit8(offset)) {
@@ -710,7 +710,7 @@
     stream = mov(stream, rax_opnd, Imm_Opnd(size_64, (int64)target), size_64);
     return call(stream, rax_opnd, size_64);
 #else
-    int32 offset = target - stream;
+    I_32 offset = target - stream;
     offset -= 5; // sub 5 bytes for this instruction
     Imm_Opnd imm(size_32, offset);
     return call(stream, imm);

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/misc/linux/dso.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/misc/linux/dso.c?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/misc/linux/dso.c (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/misc/linux/dso.c Thu May 22 06:33:38 2008
@@ -33,7 +33,7 @@
 
 APR_DECLARE(apr_status_t) port_dso_load_ex(apr_dso_handle_t** handle,
 									  const char* path,
-									  uint32 mode,
+									  U_32 mode,
 									  apr_pool_t* pool){
     if (mode == PORT_DSO_DEFAULT) {
 		return apr_dso_load(handle, path, pool);

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/dso.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/dso.c?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/dso.c (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/dso.c Thu May 22 06:33:38 2008
@@ -39,7 +39,7 @@
 
 APR_DECLARE(apr_status_t) port_dso_load_ex(apr_dso_handle_t** handle,
                                            const char* path,
-                                           uint32 mode,
+                                           U_32 mode,
                                            apr_pool_t* pool){
     /*
     * FIXME Windows does not support lazy dll resolution a la Linux's RTLD_LAZY.

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/timezone.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/timezone.c?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/timezone.c (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/misc/win/timezone.c Thu May 22 06:33:38 2008
@@ -144,7 +144,7 @@
 		}
 		if (!found) {
 			/* At least try to obtain GMT offset for local time */
-			int32 bias = 0;
+			I_32 bias = 0;
 			DWORD size = sizeof(bias);
 			rv = RegQueryValueEx(hkey, "ActiveTimeBias", NULL, NULL, 
 				(LPBYTE)&bias, &size);

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_em64t.cpp Thu May 22 06:33:38 2008
@@ -21,7 +21,7 @@
 
 
 extern "C" void port_longjump_stub(void);
-#define DIR_FLAG ((uint32)0x00000400)
+#define DIR_FLAG ((U_32)0x00000400)
 
 void port_set_longjump_regs(void* fn, Registers* regs, int num, ...)
 {

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ia32.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ia32.cpp Thu May 22 06:33:38 2008
@@ -21,7 +21,7 @@
 
 
 extern "C" void port_longjump_stub(void);
-#define DIR_FLAG ((uint32)0x00000400)
+#define DIR_FLAG ((U_32)0x00000400)
 
 void port_set_longjump_regs(void* fn, Registers* regs, int num, ...)
 {
@@ -39,7 +39,7 @@
     sp = sp - rcount - 1;
     *((Registers*)(sp + 1)) = *regs;
     *sp = (void*)(sp + 1);
-    regs->ebp = (uint32)sp;
+    regs->ebp = (U_32)sp;
 
     sp = sp - num - 1;
 
@@ -56,8 +56,8 @@
     }
 
     *sp = (void*)&port_longjump_stub;
-    regs->esp = (uint32)sp;
-    regs->eip = (uint32)fn;
+    regs->esp = (U_32)sp;
+    regs->eip = (U_32)fn;
     regs->eflags = regs->eflags & ~DIR_FLAG;
 }
 
@@ -80,7 +80,7 @@
     sp = sp - rcount - 1;
     *((Registers*)(sp + 1)) = regs;
     *sp = (void*)(sp + 1);
-    regs.ebp = (uint32)sp;
+    regs.ebp = (U_32)sp;
 
     sp = sp - num - 1;
 
@@ -97,8 +97,8 @@
     }
 
     *sp = (void*)&port_longjump_stub;
-    regs.esp = (uint32)sp;
-    regs.eip = (uint32)fn;
+    regs.esp = (U_32)sp;
+    regs.eip = (U_32)fn;
     regs.eflags = regs.eflags & ~DIR_FLAG;
 
     port_transfer_to_regs(&regs);

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ipf.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ipf.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ipf.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/linux/signals_ipf.cpp Thu May 22 06:33:38 2008
@@ -197,7 +197,7 @@
 // Variables used to locate the context from the signal handler
 static int sc_nest = -1;
 static bool use_ucontext = false;
-static uint32 exam_point;
+static U_32 exam_point;
 
 /*
  * We find the true signal stack frame set-up by kernel,which is located
@@ -238,7 +238,7 @@
 volatile void locate_sigcontext(int signum)
 {
     sigcontext *sc, *found_sc;
-    uint32 *ebp = NULL;
+    U_32 *ebp = NULL;
     int i;
 
 //TODO: ADD correct stack handling here!!
@@ -246,7 +246,7 @@
 #define SC_SEARCH_WIDTH 3
     for (i = 0; i < SC_SEARCH_WIDTH; i++) {
         sc = (sigcontext *)(ebp + 3 );
-        if (sc->sc_ip == ((uint32)exam_point)) {    // found
+        if (sc->sc_ip == ((U_32)exam_point)) {    // found
             sc_nest = i;
             use_ucontext = false;
             found_sc = sc;
@@ -271,9 +271,9 @@
         } else {                    // not found
             struct ucontext *uc;
             uc = (struct ucontext *)((uint64)ebp[4]);
-            if ((ebp < (uint32 *)uc) && ((uint32 *)uc < ebp + 0x100)) {
+            if ((ebp < (U_32 *)uc) && ((U_32 *)uc < ebp + 0x100)) {
                 sc = (sigcontext *)&uc->uc_mcontext;
-                if (sc->sc_ip == ((uint32)exam_point)) {    // found
+                if (sc->sc_ip == ((U_32)exam_point)) {    // found
                     sc_nest = i;
                     use_ucontext = true;
                     found_sc = sc;
@@ -282,7 +282,7 @@
             }
         }
 
-        ebp = (uint32 *)((uint64)ebp[0]);
+        ebp = (U_32 *)((uint64)ebp[0]);
     }
 
     if (sc_nest < 0) {

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_em64t.asm
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_em64t.asm?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_em64t.asm (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_em64t.asm Thu May 22 06:33:38 2008
@@ -55,7 +55,7 @@
 ; uint64 r10;   ; 78h
 ; uint64 r11;   ; 80h
 ;
-; uint32 eflags;; 88h
+; U_32 eflags;; 88h
 ; };
 ;
 ; void port_transfer_to_regs(Registers* regs)

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_ia32.asm
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_ia32.asm?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_ia32.asm (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_asm_ia32.asm Thu May 22 06:33:38 2008
@@ -19,16 +19,16 @@
 _TEXT   SEGMENT PARA USE32 PUBLIC 'CODE'
 
 ; struct Registers {
-; uint32 eax;    +00
-; uint32 ebx;    +04
-; uint32 ecx;    +08
-; uint32 edx;    +0C
-; uint32 edi;    +10
-; uint32 esi;    +14
-; uint32 ebp;    +18
-; uint32 esp;    +1C
-; uint32 eip;    +20
-; uint32 eflags; +24
+; U_32 eax;    +00
+; U_32 ebx;    +04
+; U_32 ecx;    +08
+; U_32 edx;    +0C
+; U_32 edi;    +10
+; U_32 esi;    +14
+; U_32 ebp;    +18
+; U_32 esp;    +1C
+; U_32 eip;    +20
+; U_32 eflags; +24
 ; };
 ;
 ; void port_transfer_to_regs(Registers* regs)

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_em64t.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_em64t.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_em64t.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_em64t.cpp Thu May 22 06:33:38 2008
@@ -21,7 +21,7 @@
 
 
 extern "C" void port_longjump_stub(void);
-#define DIR_FLAG ((uint32)0x00000400)
+#define DIR_FLAG ((U_32)0x00000400)
 
 void port_set_longjump_regs(void* fn, Registers* regs, int num, ...)
 {

Modified: harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_ia32.cpp
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_ia32.cpp?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_ia32.cpp (original)
+++ harmony/enhanced/drlvm/trunk/vm/port/src/signals/win/signals_ia32.cpp Thu May 22 06:33:38 2008
@@ -43,7 +43,7 @@
 
 
 extern "C" void port_longjump_stub(void);
-#define DIR_FLAG ((uint32)0x00000400)
+#define DIR_FLAG ((U_32)0x00000400)
 
 void port_set_longjump_regs(void* fn, Registers* regs, int num, ...)
 {
@@ -61,7 +61,7 @@
     sp = sp - rcount - 1;
     *((Registers*)(sp + 1)) = *regs;
     *sp = (void*)(sp + 1);
-    regs->ebp = (uint32)sp;
+    regs->ebp = (U_32)sp;
 
     sp = sp - num - 1;
 
@@ -78,8 +78,8 @@
     }
 
     *sp = (void*)&port_longjump_stub;
-    regs->esp = (uint32)sp;
-    regs->eip = (uint32)fn;
+    regs->esp = (U_32)sp;
+    regs->eip = (U_32)fn;
     regs->eflags = regs->eflags & ~DIR_FLAG;
 }
 
@@ -102,7 +102,7 @@
     sp = sp - rcount - 1;
     *((Registers*)(sp + 1)) = regs;
     *sp = (void*)(sp + 1);
-    regs.ebp = (uint32)sp;
+    regs.ebp = (U_32)sp;
 
     sp = sp - num - 1;
 
@@ -119,8 +119,8 @@
     }
 
     *sp = (void*)&port_longjump_stub;
-    regs.esp = (uint32)sp;
-    regs.eip = (uint32)fn;
+    regs.esp = (U_32)sp;
+    regs.eip = (U_32)fn;
     regs.eflags = regs.eflags & ~DIR_FLAG;
 
     port_transfer_to_regs(&regs);

Modified: harmony/enhanced/drlvm/trunk/vm/tests/unit/thread/test_stress_suspend.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/tests/unit/thread/test_stress_suspend.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/tests/unit/thread/test_stress_suspend.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/tests/unit/thread/test_stress_suspend.h Thu May 22 06:33:38 2008
@@ -45,7 +45,7 @@
 static void JNICALL test_thread_proc(jvmtiEnv * jvmti_env, JNIEnv * jni_env, void *args);
 static IDATA HYTHREAD_PROC test_gc_request_thread_proc(void *args);
 static void JNICALL test_java_request_thread_proc(jvmtiEnv * jvmti_env, JNIEnv * jni_env, void *args);
-static uint32 test_waste_time(uint32 count);
+static U_32 test_waste_time(U_32 count);
 
 static hylatch_t wait_threads;
 static hylatch_t start;
@@ -276,7 +276,7 @@
                                      JNIEnv * jni_env,
                                      void *args)
 {
-    uint32 xx = 0;
+    U_32 xx = 0;
     IDATA status;
     hythread_t self = hythread_self();
 
@@ -315,7 +315,7 @@
 {
     char buf[1024];
     uint64 count;
-    uint32 xx = 0;
+    U_32 xx = 0;
     IDATA status;
     hythread_t test_thread = jthread_get_native_thread((jobject)args);
 
@@ -370,7 +370,7 @@
                                                   JNIEnv * jni_env,
                                                   void *args)
 {
-    uint32 xx = 0;
+    U_32 xx = 0;
     IDATA status;
     jobject test_thread = (jobject)args;
 
@@ -411,9 +411,9 @@
 
 // make it static to prevent compiler to optimize
 // reading/writing of this variable
-static uint32 waste_time_int;
+static U_32 waste_time_int;
 
-static uint32 test_waste_time(uint32 count)
+static U_32 test_waste_time(U_32 count)
 {
     for (; count; count--) {
         waste_time_int = waste_time_int * rand();

Modified: harmony/enhanced/drlvm/trunk/vm/thread/src/thread_native_basic.c
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/thread/src/thread_native_basic.c?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/thread/src/thread_native_basic.c (original)
+++ harmony/enhanced/drlvm/trunk/vm/thread/src/thread_native_basic.c Thu May 22 06:33:38 2008
@@ -883,7 +883,7 @@
 } // hythread_set_state
 
 IDATA VMCALL hythread_get_thread_id_offset() {
-    return (uint32)&((HyThread *)0)->thread_id;
+    return (U_32)&((HyThread *)0)->thread_id;
 } // hythread_get_thread_id_offset
 
 IDATA VMCALL hythread_set_thread_stop_callback(hythread_t thread,

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/Class.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/Class.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/Class.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/Class.h Thu May 22 06:33:38 2008
@@ -138,7 +138,7 @@
     } error;
 
     /** CONSTANT_Integer.*/
-    uint32 int_value;
+    U_32 int_value;
     /** CONSTANT_Float.*/
     float float_value;
     /** CONSTANT_Long and CONSTANT_Double.
@@ -146,8 +146,8 @@
     * ConstPoolEntry and leave the second ConstPoolEntry of the long/double
     * unused.*/
     struct {
-        uint32 low_bytes;
-        uint32 high_bytes;
+        U_32 low_bytes;
+        U_32 high_bytes;
     } CONSTANT_8byte;
     /** CONSTANT_NameAndType.*/
     struct {
@@ -445,7 +445,7 @@
      * in the constant pool.
      * @param[in] index - an index in the constant pool
      * @return The value of a 32-bit constant stored in the constant pool.*/
-    uint32 get_4byte(uint16 index) const {
+    U_32 get_4byte(uint16 index) const {
         assert(get_tag(index) == CONSTANT_Integer
             || get_tag(index) == CONSTANT_Float);
         return m_entries[index].int_value;
@@ -454,7 +454,7 @@
     /** Gets an integer value for a constant stored in the constant pool.
      * @param[in] index - an index in the constant pool
      * @return The value of integer constant stored in the constant pool.*/
-    uint32 get_int(uint16 index) const {
+    U_32 get_int(uint16 index) const {
         assert(get_tag(index) == CONSTANT_Integer);
         return m_entries[index].int_value;
     }
@@ -471,7 +471,7 @@
      * stored in the constant pool.
      * @param[in] index - an index in the constant pool
      * @return A value of low 32-bits of 64-bit constant.*/
-    uint32 get_8byte_low_word(uint16 index) const {
+    U_32 get_8byte_low_word(uint16 index) const {
         assert(get_tag(index) == CONSTANT_Long
             || get_tag(index) == CONSTANT_Double);
         return m_entries[index].CONSTANT_8byte.low_bytes;
@@ -481,7 +481,7 @@
      * stored in the constant pool.
      * @param[in] index - an index in the constant pool
      * @return A value of high 32-bits of 64-bit constant.*/
-    uint32 get_8byte_high_word(uint16 index) const {
+    U_32 get_8byte_high_word(uint16 index) const {
         assert(get_tag(index) == CONSTANT_Long
             || get_tag(index) == CONSTANT_Double);
         return m_entries[index].CONSTANT_8byte.high_bytes;
@@ -815,7 +815,7 @@
     Package* m_package;
 
     // Distance in the hierarchy from java/lang/Object
-    uint32 m_depth;
+    U_32 m_depth;
 
     // The field m_is_suitable_for_fast_instanceof should be 0
     // if depth==0 or depth>=vm_max_fast_instanceof_depth()
@@ -1047,7 +1047,7 @@
 
     // Number of "padding" bytes added per class instance to its fields to
     // make each field at least 32 bits
-    uint32 m_num_field_padding_bytes;
+    U_32 m_num_field_padding_bytes;
 public:
 
     /** Initializes class-member variables to their initial values.
@@ -1122,7 +1122,7 @@
     
     /** Gets depth in the hierarchy of the given class.
      * @return A number of classes in the super-class hierarchy.*/
-    uint32 get_depth() const { return m_depth; }
+    U_32 get_depth() const { return m_depth; }
     bool get_fast_instanceof_flag() const { return m_is_suitable_for_fast_instanceof; }
 
     /** Gets the vtable for the given class.

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/String_Pool.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/String_Pool.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/String_Pool.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/String_Pool.h Thu May 22 06:33:38 2008
@@ -37,7 +37,7 @@
         // raw reference to interned string if not compressing references
         ManagedObject   * raw_ref;
         // equivalent compressed reference.
-        uint32          compressed_ref;
+        U_32          compressed_ref;
     } intern;
     char bytes[STRING_PADDING];
 };

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/annotation.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/annotation.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/annotation.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/annotation.h Thu May 22 06:33:38 2008
@@ -43,11 +43,11 @@
 // Constant Java values
 ///////////////////////////////////////////////////////////////////////////////
 union Const_Java_Value {
-    uint32 i;
+    U_32 i;
     int64 j;
     struct {
-        uint32 lo_bytes;
-        uint32 hi_bytes;
+        U_32 lo_bytes;
+        U_32 hi_bytes;
     } l;
     float f;
     double d;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/bytereader.h Thu May 22 06:33:38 2008
@@ -67,28 +67,28 @@
         return true;
     } // skip
 
-    bool parse_u4_be(uint32 * val)
+    bool parse_u4_be(U_32 * val)
     {
         if(!have(4)) return false;
 
-        uint32 result = 0;
+        U_32 result = 0;
         for (int i = 0; i < 4; i++) {
-            uint32 x = (uint32) * curr++;
+            U_32 x = (U_32) * curr++;
             result = (result << 8) + x;
         }
         *val = result;
         return true;
     } // parse_u4_be
 
-    bool parse_u4_le(uint32 * val)
+    bool parse_u4_le(U_32 * val)
     {
         if(!have(4)) return false;
 
-        uint32 result = 0;
+        U_32 result = 0;
         curr += 4;
         const uint8* curr_byte = curr;
         for (int i = 0; i < 4; i++) {
-            uint32 x = (uint32) * (--curr_byte);
+            U_32 x = (U_32) * (--curr_byte);
             result = (result << 8) + x;
         }
         *val = result;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/class_member.h Thu May 22 06:33:38 2008
@@ -677,7 +677,7 @@
     uint16 _n_exceptions;           // num exceptions method can throw
     uint16 _n_handlers;             // num exception handlers in byte codes
     String** _exceptions;          // array of exceptions method can throw
-    uint32 _byte_code_length;       // num bytes of byte code
+    U_32 _byte_code_length;       // num bytes of byte code
     U_8*   _byte_codes;           // method's byte codes
     Handler *_handlers;             // array of exception handlers in code
     Method *_intf_method_for_fake_method;
@@ -713,7 +713,7 @@
     // method when it is compiled. This number does not reflect
     // multiple breakpoints that are set in the same location by
     // different environments, it counts only unique locations
-    uint32 pending_breakpoints;
+    U_32 pending_breakpoints;
 
     /** Information about methods inlined to this. */
     InlineInfo* _inline_info;
@@ -736,8 +736,8 @@
      * @param[in] addrLocationMap - native address to bytecode location
      * correspondence table
      */
-    void add_inline_info_entry(Method* method, uint32 codeSize, void* codeAddr,
-            uint32 mapLength, AddrLocation* addrLocationMap);
+    void add_inline_info_entry(Method* method, U_32 codeSize, void* codeAddr,
+            U_32 mapLength, AddrLocation* addrLocationMap);
 
     /**
      * Sends JVMTI_EVENT_COMPILED_METHOD_LOAD event for every inline method 
@@ -786,7 +786,7 @@
     void lock();
     void unlock();
 
-    uint32 get_pending_breakpoints()
+    U_32 get_pending_breakpoints()
     {
         return pending_breakpoints;
     }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/dll_jit_intf.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/dll_jit_intf.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/dll_jit_intf.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/dll_jit_intf.h Thu May 22 06:33:38 2008
@@ -83,9 +83,9 @@
         _get_root_set_for_thread_dump(this, method, enum_handle, context);
     }
 
-    uint32
+    U_32
     get_inline_depth(InlineInfoPtr  ptr,
-                     uint32         offset)
+                     U_32         offset)
     {
         if (_get_inline_depth != NULL) {
             return _get_inline_depth(this, ptr, offset);
@@ -95,8 +95,8 @@
 
     Method_Handle
     get_inlined_method(InlineInfoPtr  ptr,
-                     uint32         offset,
-                     uint32         inline_depth)
+                     U_32         offset,
+                     U_32         inline_depth)
     {
         if (_get_inlined_method != NULL) {
             return _get_inlined_method(this, ptr, offset, inline_depth);
@@ -106,8 +106,8 @@
 
     uint16
     get_inlined_bc(InlineInfoPtr  ptr,
-                     uint32         offset,
-                     uint32         inline_depth)
+                     U_32         offset,
+                     U_32         inline_depth)
     {
         if (_get_inlined_bc != NULL) {
             return _get_inlined_bc(this, ptr, offset, inline_depth);
@@ -242,23 +242,23 @@
                                       const JitFrameContext*  context
                                       );
     
-    uint32
+    U_32
     (*_get_inline_depth)(
                         JIT_Handle jit,                    
                         InlineInfoPtr  ptr, 
-                        uint32         offset);
+                        U_32         offset);
 
     Method_Handle
     (*_get_inlined_method)(JIT_Handle jit,
                             InlineInfoPtr  ptr, 
-                            uint32         offset,
-                            uint32         inline_depth);
+                            U_32         offset,
+                            U_32         inline_depth);
 
     uint16
     (*_get_inlined_bc)(JIT_Handle jit,
                             InlineInfoPtr  ptr,
-                            uint32         offset,
-                            uint32         inline_depth);
+                            U_32         offset,
+                            U_32         inline_depth);
 
     void
     (*_fix_handler_context)(JIT_Handle         jit,

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/inline_info.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/inline_info.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/inline_info.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/inline_info.h Thu May 22 06:33:38 2008
@@ -46,7 +46,7 @@
      * @param[in] addrLocationMap - native addresses to bytecode locations
      *       correspondence table
      */
-    void add(Method* method, uint32 codeSize, void* codeAddr, uint32 mapLength, 
+    void add(Method* method, U_32 codeSize, void* codeAddr, U_32 mapLength, 
             AddrLocation* addrLocationMap);
 
     /**
@@ -63,9 +63,9 @@
     struct Entry
     {
         Method* method;
-        uint32 codeSize;
+        U_32 codeSize;
         void* codeAddr;
-        uint32 mapLength;
+        U_32 mapLength;
         AddrLocation* addrLocationMap;
     };
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_export_rt.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_export_rt.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_export_rt.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_export_rt.h Thu May 22 06:33:38 2008
@@ -83,10 +83,10 @@
  * @param prt - corresponding inline info
  * @param offset - offset in native code relative to code block start
  */
-JITEXPORT uint32 
+JITEXPORT U_32 
 JIT_get_inline_depth(JIT_Handle jit, 
                      InlineInfoPtr   ptr, 
-                     uint32          offset);
+                     U_32          offset);
 
 /**
 * Returns specified inlined method (null if not found).
@@ -102,8 +102,8 @@
 JITEXPORT Method_Handle
 JIT_get_inlined_method(JIT_Handle jit, 
                        InlineInfoPtr ptr, 
-                       uint32 offset,
-                       uint32 inline_depth);
+                       U_32 offset,
+                       U_32 inline_depth);
 
 /**
 * Returns bytecode offset at specified inlined method for the native code (zero if unknown).
@@ -119,8 +119,8 @@
 JITEXPORT uint16
 JIT_get_inlined_bc(JIT_Handle jit, 
                    InlineInfoPtr ptr, 
-                   uint32 offset, 
-                   uint32 inline_depth);
+                   U_32 offset, 
+                   U_32 inline_depth);
 
 JITEXPORT void
 JIT_fix_handler_context(JIT_Handle         jit,

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_intf_cpp.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_intf_cpp.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_intf_cpp.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/jit_intf_cpp.h Thu May 22 06:33:38 2008
@@ -113,20 +113,20 @@
                                   const JitFrameContext   *context        // in
                                   ) = 0;
     
-    virtual uint32
+    virtual U_32
     get_inline_depth(InlineInfoPtr  ptr,
-                     uint32         offset) { return 0; }
+                     U_32         offset) { return 0; }
 
 
     virtual Method_Handle
     get_inlined_method(InlineInfoPtr  ptr,
-                       uint32         offset,
-                       uint32         inline_depth) { return NULL; }
+                       U_32         offset,
+                       U_32         inline_depth) { return NULL; }
 
     virtual uint16
     get_inlined_bc(InlineInfoPtr  ptr,
-                       uint32         offset,
-                       uint32         inline_depth) { return 0; }
+                       U_32         offset,
+                       U_32         inline_depth) { return 0; }
 
 
     //

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/jvmti_direct.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/jvmti_direct.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/jvmti_direct.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/jvmti_direct.h Thu May 22 06:33:38 2008
@@ -115,8 +115,8 @@
 bool jvmti_should_report_event(jvmtiEvent event_type);
 void jvmti_send_vm_start_event(Global_Env *env, JNIEnv *jni_env);
 void jvmti_send_vm_init_event(Global_Env *env);
-void jvmti_send_region_compiled_method_load_event(Method *method, uint32 codeSize, 
-                                  const void* codeAddr, uint32 mapLength, 
+void jvmti_send_region_compiled_method_load_event(Method *method, U_32 codeSize, 
+                                  const void* codeAddr, U_32 mapLength, 
                                   const AddrLocation* addrLocationMap, 
                                   const void* compileInfo);
 void jvmti_send_chunks_compiled_method_load_event(Method *method);

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/m2n.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/m2n.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/m2n.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/m2n.h Thu May 22 06:33:38 2008
@@ -41,19 +41,19 @@
 
 struct M2nFrame;
 
-typedef uint32 frame_type;
+typedef U_32 frame_type;
 
-extern const uint32 FRAME_UNKNOWN;
-extern const uint32 FRAME_NON_UNWINDABLE;
-extern const uint32 FRAME_JNI;
-extern const uint32 FRAME_COMPILATION;
-extern const uint32 FRAME_UNPOPABLE;
-extern const uint32 FRAME_POPABLE;
-extern const uint32 FRAME_POP_NOW;
-extern const uint32 FRAME_POP_DONE;
-extern const uint32 FRAME_POP_MASK;
-extern const uint32 FRAME_SAFE_POINT;
-extern const uint32 FRAME_MODIFIED_STACK;
+extern const U_32 FRAME_UNKNOWN;
+extern const U_32 FRAME_NON_UNWINDABLE;
+extern const U_32 FRAME_JNI;
+extern const U_32 FRAME_COMPILATION;
+extern const U_32 FRAME_UNPOPABLE;
+extern const U_32 FRAME_POPABLE;
+extern const U_32 FRAME_POP_NOW;
+extern const U_32 FRAME_POP_DONE;
+extern const U_32 FRAME_POP_MASK;
+extern const U_32 FRAME_SAFE_POINT;
+extern const U_32 FRAME_MODIFIED_STACK;
 
 // The pushing and popping of native frames is done only by stubs that
 // implement the managed to native transitions. These stubs use code that is

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/mon_enter_exit.h Thu May 22 06:33:38 2008
@@ -49,8 +49,8 @@
  */
  extern void (*vm_monitor_exit)(ManagedObject *p_obj);
 extern void (*vm_monitor_enter)(ManagedObject *p_obj);
-extern uint32 (*vm_monitor_try_enter)(ManagedObject *p_obj);
-extern uint32 (*vm_monitor_try_exit)(ManagedObject *p_obj);
+extern U_32 (*vm_monitor_try_enter)(ManagedObject *p_obj);
+extern U_32 (*vm_monitor_try_exit)(ManagedObject *p_obj);
 
 #define HASH_MASK 0x7e
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_generic.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_generic.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_generic.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_generic.h Thu May 22 06:33:38 2008
@@ -39,7 +39,7 @@
 generic_hashcode(ManagedObject*);
 
 /* $$$ GMJ - collides w/ a defn elsewhere
-int32
+I_32
 default_hashcode(ManagedObject*);
 */
 

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_handles.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_handles.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_handles.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_handles.h Thu May 22 06:33:38 2008
@@ -238,8 +238,8 @@
 
 struct ObjectHandlesNew {
 #ifdef _IPF_
-    uint32 capacity;
-    uint32 size;
+    U_32 capacity;
+    U_32 size;
 #else //IA32
     uint16 capacity;
     uint16 size;

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_layout.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_layout.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/slot.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/slot.h Thu May 22 06:33:38 2008
@@ -50,7 +50,7 @@
 private:
     union {
         void **raw;
-        uint32 *compressed;
+        U_32 *compressed;
         void *value;
     } content;
 
@@ -97,7 +97,7 @@
         REFS_RUNTIME_SWITCH_IF
 #ifdef REFS_RUNTIME_OR_COMPRESSED
             if (obj != NULL) {
-                *content.compressed = (uint32) ((UDATA)obj - (UDATA)heap_base);
+                *content.compressed = (U_32) ((UDATA)obj - (UDATA)heap_base);
             } else {
                 *content.compressed = 0;
             }

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_iterator.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_iterator.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_iterator.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_iterator.h Thu May 22 06:33:38 2008
@@ -340,7 +340,7 @@
  *
  * @return The number of inlined methods.
  */
-uint32 si_get_inline_depth(StackIterator* si);
+U_32 si_get_inline_depth(StackIterator* si);
 
 /**
  * Gets the method handle for the frame iterated by the stack iterator.

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_walker.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_walker.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_walker.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/stack_walker.h Thu May 22 06:33:38 2008
@@ -233,7 +233,7 @@
     CodeChunkInfo*    cci;
     JitFrameContext   c;
     M2nFrame*         m2nfl;
-    uint32            ip;
+    U_32            ip;
 };
 
 StackIterator* si_create_from_native();

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/vm_arrays.h Thu May 22 06:33:38 2008
@@ -38,7 +38,7 @@
 
 
 
-inline int32 get_vector_length(Vector_Handle vector)
+inline I_32 get_vector_length(Vector_Handle vector)
 {
     VM_Vector *v = (VM_Vector *)vector;
     return v->get_length();
@@ -46,7 +46,7 @@
 
 
 
-inline void set_vector_length(Vector_Handle vector, int32 length)
+inline void set_vector_length(Vector_Handle vector, I_32 length)
 {
     VM_Vector *v = (VM_Vector *)vector;
     v->set_length(length);
@@ -54,56 +54,56 @@
 
 
 
-inline int8 *get_vector_element_address_bool(Vector_Handle vector, int32 idx)
+inline int8 *get_vector_element_address_bool(Vector_Handle vector, I_32 idx)
 {
     return (int8 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(int8)));
 } //get_vector_element_address_bool
 
 
 
-inline int8 *get_vector_element_address_int8(Vector_Handle vector, int32 idx)
+inline int8 *get_vector_element_address_int8(Vector_Handle vector, I_32 idx)
 {
     return (int8 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(int8)));
 } //get_vector_element_address_int8
 
 
 
-inline int16 *get_vector_element_address_int16(Vector_Handle vector, int32 idx)
+inline int16 *get_vector_element_address_int16(Vector_Handle vector, I_32 idx)
 {
     return (int16 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(int16)));
 } //get_vector_element_address_int16
 
 
 
-inline uint16 *get_vector_element_address_uint16(Vector_Handle vector, int32 idx)
+inline uint16 *get_vector_element_address_uint16(Vector_Handle vector, I_32 idx)
 {
     return (uint16 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(uint16)));
 } //get_vector_element_address_uint16
 
 
 
-inline int32 *get_vector_element_address_int32(Vector_Handle vector, int32 idx)
+inline I_32 *get_vector_element_address_int32(Vector_Handle vector, I_32 idx)
 {
-    return (int32 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(int32)));
+    return (I_32 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(I_32)));
 } //get_vector_element_address_int32
 
 
 
-inline int64 *get_vector_element_address_int64(Vector_Handle vector, int32 idx)
+inline int64 *get_vector_element_address_int64(Vector_Handle vector, I_32 idx)
 {
     return (int64 *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_8 + ((POINTER_SIZE_INT)idx * sizeof(int64)));
 } //get_vector_element_address_int64
 
 
 
-inline float *get_vector_element_address_f32(Vector_Handle vector, int32 idx)
+inline float *get_vector_element_address_f32(Vector_Handle vector, I_32 idx)
 {
     return (float *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_1_2_4 + ((POINTER_SIZE_INT)idx * sizeof(float)));
 } //get_vector_element_address_f32
 
 
 
-inline double *get_vector_element_address_f64(Vector_Handle vector, int32 idx)
+inline double *get_vector_element_address_f64(Vector_Handle vector, I_32 idx)
 {
     return (double *)((POINTER_SIZE_INT)vector + (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_8 + ((POINTER_SIZE_INT)idx * sizeof(double)));
 } //get_vector_element_address_f64
@@ -112,7 +112,7 @@
 
 // 20030321 Be careful with the result of this procedure: if references are compressed the result will be
 // the address of an element containing a COMPRESSED_REFERENCE, not a ManagedObject *.
-inline ManagedObject **get_vector_element_address_ref(Vector_Handle vector, int32 idx)
+inline ManagedObject **get_vector_element_address_ref(Vector_Handle vector, I_32 idx)
 {
     return (ManagedObject **)((POINTER_SIZE_INT)vector + 
                                       (POINTER_SIZE_INT)VM_VECTOR_FIRST_ELEM_OFFSET_REF + 
@@ -127,6 +127,6 @@
 
 enum ArrayCopyResult { ACR_Okay, ACR_NullPointer, ACR_TypeMismatch, ACR_BadIndices };
 
-ArrayCopyResult array_copy(ManagedObject* src, int32 src_off, ManagedObject* dst, int32 dst_off, int32 count);
+ArrayCopyResult array_copy(ManagedObject* src, I_32 src_off, ManagedObject* dst, I_32 dst_off, I_32 count);
 
 #endif //_VM_ARRAYS_H_

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/vtable.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/vtable.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/vtable.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/vtable.h Thu May 22 06:33:38 2008
@@ -33,9 +33,9 @@
 typedef struct Intfc_Table {
 #ifdef POINTER64
     // see INTFC_TABLE_OVERHEAD
-    uint32 dummy;   // padding
+    U_32 dummy;   // padding
 #endif
-    uint32 n_entries;
+    U_32 n_entries;
     Intfc_Table_Entry entry[1];
 } Intfc_Table;
 
@@ -70,7 +70,7 @@
     Class* clss;
 
     // See the masks in vm_for_gc.h.
-    uint32 class_properties;
+    U_32 class_properties;
 
     // Offset from the top by CLASS_ALLOCATED_SIZE_OFFSET
     // The number of bytes allocated for this object. It is the same as
--- harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_layout.h (original)
+++ harmony/enhanced/drlvm/trunk/vm/vmcore/include/object_layout.h Thu May 22 06:33:38 2008
@@ -72,7 +72,7 @@
 /// Raw and compressed reference pointers
 
 typedef ManagedObject*  RAW_REFERENCE;
-typedef uint32          COMPRESSED_REFERENCE;
+typedef U_32          COMPRESSED_REFERENCE;
 
 // Useful macros: REFS_IS_COMPRESSED_MODE effectively specifies compressed mode
 // REF_SIZE returns size of type used for references
@@ -81,7 +81,7 @@
 #if defined(REFS_USE_COMPRESSED)
 
 #define REFS_IS_COMPRESSED_MODE 1
-#define REF_SIZE (sizeof(uint32))
+#define REF_SIZE (sizeof(U_32))
 #define REF_MANAGED_NULL VM_Global_State::loader_env->heap_base
 #define REF_INIT_BY_ADDR(_ref_addr_, _val_)                                 \
     *((COMPRESSED_REFERENCE*)(_ref_addr_)) = (COMPRESSED_REFERENCE)(_val_)
@@ -160,7 +160,7 @@
 #if defined(REFS_USE_COMPRESSED)
 #define STORE_REFERENCE(_object_, _slot_addr_, _value_)                     \
         gc_heap_slot_write_ref_compressed((Managed_Object_Handle)(_object_),\
-                                          (uint32*)(_slot_addr_),           \
+                                          (U_32*)(_slot_addr_),           \
                                           (Managed_Object_Handle)(_value_))
 #elif defined(REFS_USE_UNCOMPRESSED)
 #define STORE_REFERENCE(_object_, _slot_addr_, _value_)                     \
@@ -171,7 +171,7 @@
 #define STORE_REFERENCE(_object_, _slot_addr_, _value_)                     \
     if (VM_Global_State::loader_env->compress_references) {                 \
         gc_heap_slot_write_ref_compressed((Managed_Object_Handle)(_object_),\
-                                          (uint32*)(_slot_addr_),           \
+                                          (U_32*)(_slot_addr_),           \
                                           (Managed_Object_Handle)(_value_));\
     } else {                                                                \
         gc_heap_slot_write_ref((Managed_Object_Handle)(_object_),           \
@@ -185,7 +185,7 @@
 // other global slot at address "slot_addr".
 #if defined(REFS_USE_COMPRESSED)
 #define STORE_GLOBAL_REFERENCE(_slot_addr_, _value_)                    \
-        gc_heap_write_global_slot_compressed((uint32*)(_slot_addr_),    \
+        gc_heap_write_global_slot_compressed((U_32*)(_slot_addr_),    \
                                    (Managed_Object_Handle)(_value_))
 #elif defined(REFS_USE_UNCOMPRESSED)
 #define STORE_GLOBAL_REFERENCE(_slot_addr_, _value_)                    \
@@ -194,7 +194,7 @@
 #else // for REFS_USE_RUNTIME_SWITCH
 #define STORE_GLOBAL_REFERENCE(_slot_addr_, _value_)                    \
     if (VM_Global_State::loader_env->compress_references) {             \
-        gc_heap_write_global_slot_compressed((uint32*)(_slot_addr_),    \
+        gc_heap_write_global_slot_compressed((U_32*)(_slot_addr_),    \
                                   (Managed_Object_Handle)(_value_));    \
     } else {                                                            \
         gc_heap_write_global_slot((Managed_Object_Handle*)(_slot_addr_),\
@@ -206,9 +206,9 @@
 
 // The object layout is currently as follows
 //
-//    * VTable* / uint32 vt_offset  +
-//  .-* uint32 lockword             +- get_constant_header_size()
-//  |   [int32 array lenth]
+//    * VTable* / U_32 vt_offset  +
+//  .-* U_32 lockword             +- get_constant_header_size()
+//  |   [I_32 array lenth]
 //  | * [void* tag pointer]
 //  |   [padding]
 //  |   fields / array elements
@@ -221,11 +221,11 @@
 typedef struct ManagedObject {
 #if defined USE_COMPRESSED_VTABLE_POINTERS
     union {
-    uint32 vt_offset;
+    U_32 vt_offset;
     POINTER_SIZE_INT padding;
     };
     union {
-    uint32 obj_info;
+    U_32 obj_info;
     POINTER_SIZE_INT padding2;
     };
 
@@ -238,7 +238,7 @@
 #else // USE_COMPRESSED_VTABLE_POINTERS
     VTable *vt_raw;
     union {
-    uint32 obj_info;
+    U_32 obj_info;
     POINTER_SIZE_INT padding;
     };
     VTable *vt_unsafe() { return vt_raw; }
@@ -258,10 +258,10 @@
         return get_constant_header_size() + (_tag_pointer ? sizeof(void*) : 0); 
     }
 
-    uint32 get_obj_info() { return obj_info; }
-    void set_obj_info(uint32 value) { obj_info = value; }
-    uint32* get_obj_info_addr() {
-        return (uint32*)((char*)this + header_offset());
+    U_32 get_obj_info() { return obj_info; }
+    void set_obj_info(U_32 value) { obj_info = value; }
+    U_32* get_obj_info_addr() {
+        return (U_32*)((char*)this + header_offset());
     }
 
     /**
@@ -282,11 +282,11 @@
 typedef struct VM_Vector
 {
     ManagedObject object;
-    int32 length;
+    I_32 length;
 
     static size_t length_offset() { return (size_t)(&((VM_Vector*)NULL)->length); }
-    int32 get_length() { return length; }
-    void set_length(int32 len) { length = len; }
+    I_32 get_length() { return length; }
+    void set_length(I_32 len) { length = len; }
 
     void** get_tag_pointer_address() {
         assert(ManagedObject::_tag_pointer);
@@ -300,9 +300,9 @@
 
 
 // Every vector has two pointers that can be found in any VM object
 // and an int32 field to hold the length (i.e., the number of elements).
 // The combined size of those fields is:
-#define VM_VECTOR_RT_OVERHEAD ((unsigned)(ManagedObject::get_size() + sizeof(int32)))
+#define VM_VECTOR_RT_OVERHEAD ((unsigned)(ManagedObject::get_size() + sizeof(I_32)))
 
 
 // The offset to the first element of a vector with 8-byte elements.
@@ -300,9 +300,9 @@
 
 // Every vector has two pointers that can be found in any VM object
-// and an int32 field to hold the length (i.e., the number of elements).
+// and an I_32 field to hold the length (i.e., the number of elements).
 // The combined size of those fields is:

Modified: harmony/enhanced/drlvm/trunk/vm/vmcore/include/slot.h
URL: http://svn.apache.org/viewvc/harmony/enhanced/drlvm/trunk/vm/vmcore/include/slot.h?rev=659108&r1=659107&r2=659108&view=diff
==============================================================================